@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/ErrorHandling/RequireUseOfExceptions.pm $
-#     $Date: 2007-08-12 11:37:37 -0500 (Sun, 12 Aug 2007) $
-#   $Author: chrisdolan $
-# $Revision: 1831 $
+#     $Date: 2008-05-26 16:44:53 -0500 (Mon, 26 May 2008) $
+#   $Author: clonezone $
+# $Revision: 2407 $
 ##############################################################################
 
 package Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions;
@@ -10,23 +10,24 @@ package Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions;
 use 5.006;
 use strict;
 use warnings;
+
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.16;
+our $VERSION = '1.000';
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return () }
 sub default_severity     { return $SEVERITY_HIGH }
-sub default_themes       { return qw( more maintenance ) }
+sub default_themes       { return qw< more maintenance > }
 sub applies_to           { return 'PPI::Token::Word' }
+sub supported_parameters { return () }
 
 #-----------------------------------------------------------------------------
 
-Readonly::Hash my %FATAL_FUNCTIONS => hashify(qw{ die croak confess });
+Readonly::Hash my %FATAL_FUNCTIONS => hashify(qw< die croak confess >);
 
 sub violates {
     my ( $self, $elem, undef ) = @_;
@@ -52,7 +53,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions
+Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions - Use exceptions instead of C<die>, C<croak>, or C<confess>.
 
 =head1 AFFILIATION
 
@@ -70,7 +71,7 @@ Elliot Shank C<< <perl@galumph.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2008 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -85,4 +86,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
