@@ -1,8 +1,8 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/ValuesAndExpressions/RestrictLongStrings.pm $
-#     $Date: 2007-08-12 11:37:37 -0500 (Sun, 12 Aug 2007) $
-#   $Author: chrisdolan $
-# $Revision: 1831 $
+#     $Date: 2008-05-26 16:44:53 -0500 (Mon, 26 May 2008) $
+#   $Author: clonezone $
+# $Revision: 2407 $
 ########################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings;
@@ -10,42 +10,36 @@ package Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings;
 use 5.006;
 use strict;
 use warnings;
+
 use Carp;
 use Readonly;
+
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.16;
-
-Readonly my $DEFAULT_MAX_STRING_LENGTH => 78;
+our $VERSION = '1.000';
 
 #---------------------------------------------------------------------------
 
-my $desc = 'Long string mixed with code';
-my $expl = 'Put long strings in their own subroutine or split them';
+Readonly::Scalar my $DESC => 'Long string mixed with code';
+Readonly::Scalar my $EXPL =>
+    'Put long strings in their own subroutine or split them';
 
 #---------------------------------------------------------------------------
 
 sub default_severity { return $SEVERITY_LOW }
-sub default_themes   { return qw(more readability) }
+sub default_themes   { return qw< more readability > }
 sub applies_to       { return 'PPI::Token::Quote' }
 
-#---------------------------------------------------------------------------
-
-sub new {
-    my ( $class, %config ) = @_;
-    my $self = bless {}, $class;
-
-    $self->{_max_length} = $DEFAULT_MAX_STRING_LENGTH;
-    if ( $config{max_length} ) {
-        if ( $config{max_length} =~ m/\A \s* (\d+) \s* \z/xms && $1 > 0 ) {
-            $self->{_max_length} = $1;
-        } else {
-            croak 'Invalid RestrictLongStrings length in Perl::Critic config';
-        }
-    }
-
-    return $self;
+sub supported_parameters {
+    return (
+        {   name            => 'max_length',
+            description     => 'The maximum line length to allow.',
+            default_string  => '78',
+            behavior        => 'integer',
+            integer_minimum => 1,
+        },
+    );
 }
 
 #---------------------------------------------------------------------------
@@ -71,7 +65,7 @@ sub violates {
         }
     }
 
-    return $self->violation( $desc, $expl, $elem );
+    return $self->violation( $DESC, $EXPL, $elem );
 }
 
 1;
@@ -86,11 +80,11 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings - Stop mixing long strings with code
+Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings - Stop mixing long strings with code.
 
 =head1 AFFILIATION
 
-This policy is part of L<Perl::Critic::More>, a bleading edge supplement to
+This policy is part of L<Perl::Critic::More>, a bleeding edge supplement to
 L<Perl::Critic>.
 
 =head1 DESCRIPTION
@@ -115,7 +109,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2007 Chris Dolan
+Copyright (c) 2006-2008 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -130,4 +124,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
